# Anomaly Detection in Oil Pumps Using Isolation Forest

## Project Overview
This project aims to detect anomalies in oil pumps using **Isolation Forest**, a machine learning algorithm. The primary objective is to develop an early warning system for potential equipment failures, enabling predictive maintenance and improving operational efficiency in the oil and gas industry.

## Key Features
- **Data**: Synthetic data is generated for pump features like vibration, temperature, pressure, and flow rate.
- **Model**: We use the Isolation Forest algorithm to identify anomalies in the data.
- **Results**: The model achieves 93% accuracy, with 100% recall for anomalies, making it effective at detecting potential issues.
- **Application**: This approach can be adapted for real-world predictive maintenance tasks in industries like oil & gas, manufacturing, and more.

## Project Structure
- **`anomaly_detection_oil_pumps.ipynb`**: The main Jupyter Notebook with step-by-step explanations and code.
- **`synthetic_data.csv`** (optional): The CSV file containing the synthetic dataset used in the notebook.
- **`README.md`**: This file that explains the project.
- **`requirements.txt`**: A file containing all the dependencies needed to run the project.

## Installation
1. Clone the repository or download the `.ipynb` file.
2. Install the required dependencies using the following command:
   ```bash
   pip install -r requirements.txt
   
## How to Run the Project
1. Open the anomaly_detection_oil_pumps.ipynb file in Jupyter Notebook or Google Colab.
2. Run the cells sequentially to generate synthetic data, build the Isolation Forest model, and evaluate its performance.

## Dataset
The dataset consists of synthetic sensor readings from oil pumps:

- **vibration**: Measures pump vibration.
- **temperature**: Records the pump's temperature.
- **pressure**: The oil pressure in the pump.
- **flow_rate**: The rate of oil flowing through the pump.
- **is_anomaly**: A label indicating whether the data point is normal (`0`) or an anomaly (`1`).

## Results Summary
### Confusion Matrix:
- True Positives (Anomalies detected correctly): 15
- False Positives (Normal points incorrectly flagged as anomalies): 20
- True Negatives (Normal points correctly identified): 265
- False Negatives (Anomalies missed): 0
### Classification Report:
- Precision:
  - Normal: 100%,
  - Anomaly: 43%
- Recall:
  - Normal: 93%,
  - Anomaly: 100%
- Accuracy: 93%

## Requirements
To run this project, the following Python libraries are required:

- `numpy`
- `pandas`
- `scikit-learn`
- `matplotlib`
- `seaborn`
- `jupyter`

Install the dependencies by running:
```bash
pip install -r requirements.txt
```

## Future Work
- Apply the Isolation Forest model on real-world datasets.
- Integrate other algorithms (e.g., One-Class SVM) to compare results.
- Test model performance on larger datasets and different feature sets.

## License
This project is licensed under the MIT License.
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)